# Generated by roxygen2: do not edit by hand

export(app_descriptive)
export(app_inference)
export(app_linear_regression)
export(app_logistic_regression)
export(app_rfm_analysis)
export(app_vistributions)
export(app_visualizer)
export(xpl_gvar)
export(xpl_nsignC)
importFrom(Rcpp,sourceCpp)
importFrom(utils,install.packages)
importFrom(utils,menu)
importFrom(utils,packageVersion)
useDynLib(xplorerr)
