library(shiny)
library(ggplot2)
library(plotly)
library(highcharter)
library(dplyr)
library(purrr)
library(tidyr)
library(tibble)
library(readxl)
library(readr)
library(jsonlite)
library(magrittr)
library(tools)
library(lubridate)
library(scales)
library(stringr)
library(DT)

shinyServer(function(input, output, session) {
    
    source("logic/logic_dataoptions.R", local = T)
    source("logic/logic_upload.R", local = T)
    source("logic/logic_transform2.R", local = T)
    source("logic/logic_select.R", local = T)
    source("logic/logic_filter.R", local = T)
    source("logic/logic_screen.R", local = T)
    source("logic/logic_view.R", local = T)
    source("logic/logic_bar.R", local = T)
    source("logic/logic_bar2.R", local = T)
    source("logic/logic_box.R", local = T)
    source("logic/logic_box2.R", local = T)
    source("logic/logic_hist.R", local = T)
    source("logic/logic_line.R", local = T)
    source("logic/logic_pie.R", local = T)
    source("logic/logic_pie3d.R", local = T)
    source("logic/logic_scatter.R", local = T)
    source("logic/logic_gscatter.R", local = T)
    source("logic/logic_home.R", local = T)
    source("logic/logic_vizlib.R", local = T)
    source("logic/logic_gbar.R", local = T)
    source("logic/logic_gbar2.R", local = T)
    source("logic/logic_gbox.R", local = T)
    source("logic/logic_gbox2.R", local = T)
    source("logic/logic_ghist.R", local = T)
    source("logic/logic_gpie.R", local = T)
    source("logic/logic_gline.R", local = T)
    source("logic/logic_gline2.R", local = T)
    source("logic/logic_bar_plot_1.R", local = T)
    source("logic/logic_bar_plot_2.R", local = T)
    source("logic/logic_box_plot_1.R", local = T)
    source("logic/logic_box_plot_2.R", local = T)
    source("logic/logic_scatter_prh.R", local = T)
    source("logic/logic_line_prh.R", local = T)
    source("logic/logic_hist_prh.R", local = T)
    source("logic/logic_pie_prh.R", local = T)
    source("logic/logic_exit_button.R", local = T)
})


